<?php
/**
 * Custom template tags for Collect
 *
 * Eventually, some of the functionality here could be replaced by core features.
 *
 * @package WordPress
 * @subpackage Collect
 * @since Collect 1.0
 */
if ( ! function_exists( 'collect_default_menu' ) ) {
	function collect_default_menu( $args ) {
		$output = wp_list_categories( array(
			'title_li' => '',
			'echo' => 0,
			'number' => 5,
			'depth' => 1,
		) );

		echo '<ul class="' . esc_attr( $args['menu_class'] ) . '">' . $output . '</ul>';
	}
}

if ( ! function_exists( 'collect_search_title' ) ) {
	function collect_search_title() {
		global $wp_query;
	    $num = $wp_query->found_posts;
		printf( __( '%1$s search results for "%2$s"', 'collect'),
		    absint( $wp_query->found_posts ),
		    esc_html( get_search_query() )
		);
	}
}

if ( ! function_exists( 'collect_sidebar_nav' ) ) {
	function collect_sidebar_nav() {
		?>
		<nav class="main-navigation widget" role="navigation">
			<h3 class="screen-reader-text"><?php _e( 'Main menu', 'collect' ); ?></h3>
			<?php
			wp_nav_menu( array(
				'theme_location' => 'primary',
				'container' => '',
				'fallback_cb' => 'collect_default_menu'
			) );
			?>
		</nav>
		<?php
	}
}

if ( ! function_exists( 'collect_header_style' ) ) {
	function collect_header_style() {
		$header_text_color = get_header_textcolor();

		// If no custom options for text are set, let's bail
		// get_header_textcolor() options: HEADER_TEXTCOLOR is default, hide text (returns 'blank') or any hex value
		if ( HEADER_TEXTCOLOR == $header_text_color ) {
			return;
		}

		// If we get this far, we have custom styles. Let's do this.
		?>
		<style type="text/css">
		<?php
			// Has the text been hidden?
			if ( 'blank' == $header_text_color ) :
		?>
			.site-title,
			.site-description {
				position: absolute;
				clip: rect(1px, 1px, 1px, 1px);
			}
		<?php endif; ?>
		</style>
		<?php
	}
}

add_filter( 'excerpt_length', 'collect_excerpt_length', 999 );
if ( ! function_exists( 'collect_excerpt_length' ) ) {
	function collect_excerpt_length( $length ) {
		return 20;
	}
}

add_filter( 'excerpt_more', 'collect_excerpt_more' );
if ( ! function_exists( 'collect_excerpt_more' ) ) {
	function collect_excerpt_more( $more ) {
		$collect_default_theme_options = collect_default_theme_options();

		return '&hellip; <div><a class="more-link" href="' . esc_url( get_permalink() ) . '">' . collect_sanitize_text( get_theme_mod( 'read_more_text', $collect_default_theme_options['read_more_text'] ) ) . ' <span class="screen-reader-text">' . get_the_title() . '</span></a></div>';
	}
}

add_filter( 'the_content_more_link', 'collect_remove_more_link_scroll' );
if ( ! function_exists( 'collect_remove_more_link_scroll' ) ) {
	function collect_remove_more_link_scroll( $link ) {
		return preg_replace( '|#more-[0-9]+|', '', $link );
	}
}